import { Component, OnInit, ViewChild } from '@angular/core';
import { IgxDataChartComponent, IgxStackedAreaSeriesComponent, IgxStackedFragmentSeriesComponent, IgxStackedLineSeriesComponent } from "igniteui-angular-charts";
import { COLUMNS, HORIZON, SALES } from './data';

@Component({
  selector: 'app-chart-page',
  templateUrl: './chart-page.component.html',
  styleUrls: ['./chart-page.component.scss']
})
export class ChartPageComponent implements OnInit {

  @ViewChild("chart", { static: false}) public chart : IgxDataChartComponent;

  columns:any[] = COLUMNS;
  compareTimePeriods:string[] = HORIZON;
  designs:string[] = [];
  height:number = window.innerHeight;
  outData1:any[] = [];
  outData2:any[] = [];
  parameterData:any[] = SALES;
  scenario1:string = 'PLAN_2021_51';
  scenario2:string = 'BETA_2021_51_CS';



  constructor() { }

  // ngOnInit(): void {
    // let previousItem: any = null, index: number = (this.data1.length - 1) / 2; //Calculates the middle of the category x-axis plot area
    // for(let i=0; i<this.data1.length; i++){

    //   let item1 = this.data1[1], item2 = this.data1[2],
    //     value1 = 0, value2 = 0,
    //     label = this.seriesTitles[i];

    //   switch (label) {
    //     case "Classic AT-AT": {
    //       value1 = item1.StarWarsATAT;
    //       value2 = item2.StarWarsATAT;
    //       break;
    //     }
    //     case "First Order AT-AT": {
    //       value1 = item1.StarWarsOrderAT;
    //       value2 = item2.StarWarsOrderAT;
    //       break;
    //     }
    //     case "Avengers Tower": {
    //       value1 = item1.MarvelTower;
    //       value2 = item2.MarvelTower;
    //       break;
    //     }
    //     case "Stark's Mansion": {
    //       value1 = item1.MarvelMansion;
    //       value2 = item2.MarvelMansion;
    //       break;
    //     }
    //   }

    //   let calloutValue = (value1 + value2) / 2; //The midpoint between the two points. Needed because index is fractional. Not needed if it's not fractional
    //   calloutValue = previousItem ? calloutValue + previousItem.Value : (calloutValue / 2) - 1;

    //   previousItem = { Index: index, Value: calloutValue, Label: this.seriesTitles[i] };
    //   this.calloutData.push(previousItem);
    // }
  // }

  ngOnInit(): void {
    this.parameterData.forEach((d) => { //build designs array
      if (this.designs.indexOf(d.Design) < 0 && d.Design !== undefined) {
        this.designs.push(d.Design);
      }
    });
  }

  itemSelected(e:any) {
    if(e == 1){
      this.populateChart();
    }
  }

  populateChart(){
    this.buildOutData();
    this.chart.series.clear(); //This will clear the manually generated / added series (not the ones in HTML)

    if (this.chart.actualSeries.length > 0) {
      let areaSeries: IgxStackedAreaSeriesComponent = this.chart.actualSeries[0] as IgxStackedAreaSeriesComponent,
          lineSeries: IgxStackedLineSeriesComponent = this.chart.actualSeries[1] as IgxStackedLineSeriesComponent;

      //These two lines will clear the existing fragments
      areaSeries.series.clear();
      lineSeries.series.clear();

      this.designs.forEach((d) => {
        let areaFrag: IgxStackedFragmentSeriesComponent = new IgxStackedFragmentSeriesComponent(),
          lineFrag: IgxStackedFragmentSeriesComponent = new IgxStackedFragmentSeriesComponent();

        areaFrag.valueMemberPath = d;
        areaFrag.title = d;
        areaSeries.series.add(areaFrag);
        lineFrag.valueMemberPath = d;
        lineFrag.title = d;
        lineSeries.series.add(lineFrag);
      });

      areaSeries.renderSeries(false);
      lineSeries.renderSeries(false);
    }
  }

  buildOutData() {
    let scen1Data: any[] = this.parameterData.filter((d) => d.Scenario === this.scenario1 && d.Design !== undefined),
        scen2Data: any[] = this.parameterData.filter((d) => d.Scenario === this.scenario2 && d.Design !== undefined);

    //this.outData1 = [], this.outData2 = [];
    this.outData1 = [];
    this.outData2 = [];

    scen1Data.forEach((d, j) => {
      let design: string = d.Design;
      this.compareTimePeriods.forEach((p, i) => {
        if (this.outData1[i] === undefined) { this.outData1[i] = { Date: p, Year: p.slice(0, 4) }; }
        if (this.outData2[i] === undefined) { this.outData2[i] = { Date: p, Year: p.slice(0, 4) }; }

        if (design in this.outData1[i]) { this.outData1[i][design] += d[p] > 0 ? d[p] : 0; }
        else { this.outData1[i][design] = d[p] > 0 ? d[p] : 0; }

        if (design in this.outData2[i]) { this.outData2[i][design] += d[p] > 0 ? d[p] : 0; }
        else { this.outData2[i][design] = scen2Data[j][p] > 0 ? scen2Data[j][p] : 0; }
      });
    });
  }
}
